@@ -156,11 +156,12 @@ int detect_hypervisor(int *hypervisor) {
 
 		*hypervisor = HYPER_OTHER;
 
-		int id;
-		for (id = HYPER_NONE + 1; id < HYPER_LAST; id++) {
-			if (strcmp(hypervisor_ids[id], sig.text) == 0) {
-				*hypervisor = id;
-				break;
+		if (*sig.text) {
+			for (int id = HYPER_NONE + 1; id < HYPER_LAST; id++) {
+				if (strcmp(hypervisor_ids[id], sig.text) == 0) {
+					*hypervisor = id;
+					break;
+				}
 			}
 		}
 
